@@ -39,20 +39,19 @@
 
 #ifndef HAVE_SECURE_RANDOM
 
-#include <bcrypt.h>
-#include <ntstatus.h>
 #include <windows.h>
+#include <bcrypt.h>
 
 ZIP_EXTERN bool
 zip_secure_random(zip_uint8_t *buffer, zip_uint16_t length) {
     BCRYPT_ALG_HANDLE hAlg = NULL;
     NTSTATUS hr = BCryptOpenAlgorithmProvider(&hAlg, BCRYPT_RNG_ALGORITHM, MS_PRIMITIVE_PROVIDER, 0);
-    if (hr != STATUS_SUCCESS || hAlg == NULL) {
+    if (!BCRYPT_SUCCESS(hr) || hAlg == NULL) {
         return false;
     }
     hr = BCryptGenRandom(&hAlg, buffer, length, 0);
     BCryptCloseAlgorithmProvider(&hAlg, 0);
-    if (hr != STATUS_SUCCESS) {
+    if (!BCRYPT_SUCCESS(hr)) {
         return false;
     }
     return true;
